"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StreamingConnection = void 0;
class StreamingConnection {
    constructor(url, onMessage, logger) {
        this.url = url;
        this.onMessage = onMessage;
        this.logger = logger;
        this.openConnection();
    }
    openConnection() {
        if (typeof EventSource === 'undefined') {
            this.logger.warn('StreamingConnection not opened. EventSource is not available.');
            return;
        }
        this.connection = new EventSource(this.url, { withCredentials: true });
        this.connection.onmessage = (event) => {
            this.onMessage(event.data);
        };
        this.connection.onerror = () => {
            this.logger.warn('StreamingConnection warning. Connection failed to establish.');
        };
        this.connection.onopen = () => {
            this.logger.debug('StreamingConnection opened');
        };
    }
    isConnected() {
        var _a, _b;
        return ((_a = this.connection) === null || _a === void 0 ? void 0 : _a.readyState) === ((_b = this.connection) === null || _b === void 0 ? void 0 : _b.OPEN);
    }
    reopen() {
        if (!this.isConnected()) {
            this.close();
            this.openConnection();
        }
    }
    close() {
        var _a;
        (_a = this.connection) === null || _a === void 0 ? void 0 : _a.close();
    }
}
exports.StreamingConnection = StreamingConnection;
//# sourceMappingURL=StreamingConnection.js.map