"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateEventPayload = exports.checkParamType = exports.checkIfDefined = exports.checkParamDefined = exports.serializeUserSearchParams = void 0;
const RequestEvent_1 = require("./RequestEvent");
const convertToQueryFriendlyFormat = (property) => {
    if (property instanceof Date) {
        return property.getTime();
    }
    if (typeof property === 'object') {
        return JSON.stringify(property);
    }
    return property;
};
const serializeUserSearchParams = (user, queryParams) => {
    for (const key in user) {
        const userProperty = convertToQueryFriendlyFormat(user[key]);
        if (userProperty !== null && userProperty !== undefined) {
            queryParams.append(key, userProperty);
        }
    }
};
exports.serializeUserSearchParams = serializeUserSearchParams;
const checkParamDefined = (name, param) => {
    if (!(0, exports.checkIfDefined)(param)) {
        throw new Error(`Missing parameter: ${name}`);
    }
};
exports.checkParamDefined = checkParamDefined;
const checkIfDefined = (variable) => {
    if (variable === undefined || variable === null) {
        return false;
    }
    return true;
};
exports.checkIfDefined = checkIfDefined;
const checkParamType = (name, param, type) => {
    if (!param) {
        throw new Error(`Missing parameter: ${name}`);
    }
    if (typeof param !== type) {
        throw new Error(`${name} is not of type ${type}`);
    }
};
exports.checkParamType = checkParamType;
function generateEventPayload(config, user, events) {
    return {
        events: events.map((event) => {
            return new RequestEvent_1.DVCRequestEvent(event, user.user_id, config === null || config === void 0 ? void 0 : config.featureVariationMap);
        }),
        user,
    };
}
exports.generateEventPayload = generateEventPayload;
exports.default = {
    serializeUserSearchParams: exports.serializeUserSearchParams,
    checkParamDefined: exports.checkParamDefined,
    generateEventPayload,
};
//# sourceMappingURL=utils.js.map