import { DevCycleEvent, DevCycleOptions } from './types';
import { DVCPopulatedUser } from './User';
import axios, { AxiosResponse } from 'axios';
import { BucketedUserConfig, DVCLogger } from '@devcycle/types';
export declare const HOST = ".devcycle.com";
export declare const CLIENT_SDK_URL: string;
export declare const EVENT_URL: string;
export declare const CONFIG_PATH = "/v1/sdkConfig";
export declare const EVENTS_PATH = "/v1/events";
export declare const SAVE_ENTITY_PATH = "/v1/edgedb";
export declare const baseRequestHeaders: (sdkKey?: string) => Record<string, string>;
/**
 * Base Requests
 */
export declare const get: (url: string) => Promise<AxiosResponse>;
export declare const post: (url: string, sdkKey: string, body: Record<string, unknown>) => Promise<AxiosResponse>;
export declare const patch: (url: string, sdkKey: string, body: Record<string, unknown>) => Promise<AxiosResponse>;
/**
 * Endpoints
 */
export declare const getConfigJson: (sdkKey: string, user: DVCPopulatedUser, logger: DVCLogger, options?: DevCycleOptions, extraParams?: {
    sse: boolean;
    lastModified?: number;
    etag?: string;
}) => Promise<BucketedUserConfig>;
export declare const publishEvents: (sdkKey: string | null, config: BucketedUserConfig | null, user: DVCPopulatedUser, events: DevCycleEvent[], logger: DVCLogger, options?: DevCycleOptions) => Promise<AxiosResponse>;
export declare const saveEntity: (user: DVCPopulatedUser, sdkKey: string, logger: DVCLogger, options?: DevCycleOptions) => Promise<AxiosResponse>;
declare const _default: {
    get: (url: string) => Promise<axios.AxiosResponse<any, any>>;
    post: (url: string, sdkKey: string, body: Record<string, unknown>) => Promise<axios.AxiosResponse<any, any>>;
    getConfigJson: (sdkKey: string, user: DVCPopulatedUser, logger: DVCLogger, options?: DevCycleOptions | undefined, extraParams?: {
        sse: boolean;
        lastModified?: number | undefined;
        etag?: string | undefined;
    } | undefined) => Promise<BucketedUserConfig>;
    publishEvents: (sdkKey: string | null, config: BucketedUserConfig | null, user: DVCPopulatedUser, events: DevCycleEvent[], logger: DVCLogger, options?: DevCycleOptions | undefined) => Promise<axios.AxiosResponse<any, any>>;
};
export default _default;
